[Scummvm-cvs-logs] SF.net SVN: scummvm:[45230] scummvm/trunk/engines/sci

mthreepwood at users.sourceforge.net mthreepwood at users.sourceforge.net
Sun Oct 18 20:47:53 CEST 2009


Revision: 45230
          http://scummvm.svn.sourceforge.net/scummvm/?rev=45230&view=rev
Author:   mthreepwood
Date:     2009-10-18 18:47:53 +0000 (Sun, 18 Oct 2009)

Log Message:
-----------
Move the SeqDecoder to the Sci namespace, it makes more sense than Graphics because it's only used in Sci.

Modified Paths:
--------------
    scummvm/trunk/engines/sci/console.cpp
    scummvm/trunk/engines/sci/engine/kgraphics.cpp
    scummvm/trunk/engines/sci/seq_decoder.cpp
    scummvm/trunk/engines/sci/seq_decoder.h

Modified: scummvm/trunk/engines/sci/console.cpp
===================================================================
--- scummvm/trunk/engines/sci/console.cpp	2009-10-18 18:09:23 UTC (rev 45229)
+++ scummvm/trunk/engines/sci/console.cpp	2009-10-18 18:47:53 UTC (rev 45230)
@@ -216,7 +216,7 @@
 		_vm->_gamestate->_gui->hideCursor();
 
 		if (_videoFile.hasSuffix(".seq")) {
-			Graphics::SeqDecoder *seqDecoder = new Graphics::SeqDecoder();
+			SeqDecoder *seqDecoder = new SeqDecoder();
 			Graphics::VideoPlayer *player = new Graphics::VideoPlayer(seqDecoder);
 			if (seqDecoder->loadFile(_videoFile.c_str(), _videoFrameDelay))
 				player->playVideo();

Modified: scummvm/trunk/engines/sci/engine/kgraphics.cpp
===================================================================
--- scummvm/trunk/engines/sci/engine/kgraphics.cpp	2009-10-18 18:09:23 UTC (rev 45229)
+++ scummvm/trunk/engines/sci/engine/kgraphics.cpp	2009-10-18 18:47:53 UTC (rev 45230)
@@ -1027,7 +1027,7 @@
 		Common::String filename = s->_segMan->getString(argv[0]);
 		int delay = argv[1].toUint16(); // Time between frames in ticks
 
-		Graphics::SeqDecoder *seqDecoder = new Graphics::SeqDecoder();
+		SeqDecoder *seqDecoder = new SeqDecoder();
 		Graphics::VideoPlayer *player = new Graphics::VideoPlayer(seqDecoder);
 		if (seqDecoder->loadFile(filename.c_str(), delay))
 			player->playVideo();

Modified: scummvm/trunk/engines/sci/seq_decoder.cpp
===================================================================
--- scummvm/trunk/engines/sci/seq_decoder.cpp	2009-10-18 18:09:23 UTC (rev 45229)
+++ scummvm/trunk/engines/sci/seq_decoder.cpp	2009-10-18 18:47:53 UTC (rev 45230)
@@ -33,7 +33,7 @@
 
 #include "sci/seq_decoder.h"
 
-namespace Graphics {
+namespace Sci {
 
 enum seqPalTypes {
 	kSeqPalVariable = 0,
@@ -238,4 +238,4 @@
 	return true;
 }
 
-} // End of namespace Graphics
+} // End of namespace Sci

Modified: scummvm/trunk/engines/sci/seq_decoder.h
===================================================================
--- scummvm/trunk/engines/sci/seq_decoder.h	2009-10-18 18:09:23 UTC (rev 45229)
+++ scummvm/trunk/engines/sci/seq_decoder.h	2009-10-18 18:47:53 UTC (rev 45230)
@@ -28,12 +28,12 @@
 
 #include "graphics/video/video_player.h"
 
-namespace Graphics {
+namespace Sci {
 
 /**
  * Implementation of the Sierra SEQ decoder, used in KQ6 DOS floppy/CD and GK1 DOS
  */
-class SeqDecoder : public VideoDecoder {
+class SeqDecoder : public Graphics::VideoDecoder {
 public:
 	SeqDecoder() {}
 	virtual ~SeqDecoder();
@@ -62,6 +62,6 @@
 	bool decodeFrame(byte *rleData, int rleSize, byte *litData, int litSize, byte *dest, int left, int width, int height, int colorKey);
 };
 
-} // End of namespace Graphics
+} // End of namespace Sci
 
 #endif


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list